@@ -139,6 +139,9 @@ class Menu_View(OrderedTable_View):
             return child
         elif column == 'workflow_state':
             path = get_value(item, 'path')
+            if not path:
+                # Do not display a workflow state if there is no path defined.
+                return
             # Get the reference and path
             ref, path = get_reference_and_path(path)
             if ref.scheme or path.count(';'):
@@ -239,7 +242,8 @@ class Menu_View(OrderedTable_View):
                 index = index + 1
                 name = checkid('%s%03d' % (base, index))
 
-            object = Menu.make_resource(Menu, parent, name)
+            cls = resource.parent.class_menu
+            object = cls.make_resource(cls, parent, name)
 
             # update the parent record
             handler.update_record(parent_id, **{'child': name})
@@ -540,8 +544,7 @@ class MenuFolder(Folder):
         Folder._make_resource(cls, folder, name, **kw)
         # Menu root
         cls_menu = cls.class_menu
-        cls_menu._make_resource(cls_menu, folder, '%s/menu' % name,
-                                title={'en': u"Menu", 'fr': u"Menu"})
+        cls_menu._make_resource(cls_menu, folder, '%s/menu' % name)
 
 
     def get_document_types(self):
