@@ -151,6 +151,11 @@ class Issue(Folder):
         return self.parent.get_resource('calendar')
 
 
+    def load_handlers(self):
+        Folder.load_handlers(self)
+        self.get_history()
+
+
     def get_history(self):
         return self.handler.get_handler('.history', cls=History)
 
@@ -273,7 +278,10 @@ class Issue(Folder):
                                         comment=comment)
         # Notify / Send
         for to_addr in to_addrs:
-            to_addr = users.get_resource(to_addr).get_property('email')
+            user = root.get_user(to_addr)
+            if not user:
+                continue
+            to_addr = user.get_property('email')
             root.send_email(to_addr, subject, text=body)
 
 
