@@ -1,5 +1,5 @@
 /**
- * $Id: editor_template_src.js 925 2008-09-11 11:25:26Z spocke $
+ * $Id: editor_template_src.js 960 2008-11-12 18:30:32Z spocke $
  *
  * @author Moxiecode
  * @copyright Copyright  2004-2008, Moxiecode Systems AB, All rights reserved.
@@ -325,6 +325,9 @@
 			if (v = s.theme_advanced_text_colors)
 				o.colors = v;
 
+			if (s.theme_advanced_default_foreground_color)
+				o.default_color = s.theme_advanced_default_foreground_color;
+
 			o.title = 'advanced.forecolor_desc';
 			o.cmd = 'ForeColor';
 			o.scope = this;
@@ -351,6 +354,9 @@
 			if (v = s.theme_advanced_background_colors)
 				o.colors = v;
 
+			if (s.theme_advanced_default_background_color)
+				o.default_color = s.theme_advanced_default_background_color;
+
 			o.title = 'advanced.backcolor_desc';
 			o.cmd = 'HiliteColor';
 			o.scope = this;
